{ ---------------------------------------------------------
    Name:          EditParams.pas
    Version:       0.2
    Date:          1/4/2000
    Description:   IPv6Srv EditParams unit
    Author:        David Fernndez (david@dit.upm.es)
                   http://www.dit.upm.es/bti
                   Copyright DIT-UPM, 2000
  --------------------------------------------------------- }

unit EditParams;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  TForm1 = class(TForm)
    bLoad: TButton;
    bSave: TButton;
    Memo1: TMemo;
    Button1: TButton;
    procedure FormCreate(Sender: TObject);
    procedure bLoadClick(Sender: TObject);
    procedure bSaveClick(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure FormCloseQuery(Sender: TObject; var CanClose: Boolean);
  private
    procedure SaveToRegistry;
    procedure ShowUsage;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

uses
  IPv6CfgService, Registry;

{$R *.DFM}

const
  MSRIPv6Path = 'Software\Microsoft\Tcpip6\CurrentVersion\InitCommands';


procedure TForm1.ShowUsage;
var
  tp: array[0..99] of char;
begin
  GetTempPath (100, @tp);
  ShowMessage ('''ipv6srv'' is a simple NT Service that executes MSRIPv6 configuration commands at startup.' +
               chr(13)+chr(13)+
               'Usage:   ipv6 /install        # installs ipv6srv as a service in the system' + chr(13) +
               '              ipv6 /uninstall     # uninstalls ipv6srv as a service' + chr(13) +
               '              ipv6 /edit            # edits the list of init. commands' + chr(13) +
               '              ipv6 /exe             # reexecutes init. commands' + chr(13) +
               chr(13) +
               'results of command executions are written to a log file;' + tp + 'ipv6srv.log'+
               chr(13) + chr(13) +
               'Written by David Fernndez, April 2000' + chr(13) +
               'Copyright DIT-UPM, 2000' + '     http://ww.dit.upm.es/bti'
               );
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  bLoadClick (NIL)
  //ShowMessage (cmdline)
end;

procedure TForm1.bLoadClick(Sender: TObject);
var
  SI: TStartupInfo;
  PI: TProcessInformation;
  res: bool;
  reg: TRegistry;
  s: string;
  st: TStringList;
  i: integer;
begin
  reg := TRegistry.Create;
  Reg.rootkey := HKEY_LOCAL_MACHINE;
  Res := reg.OpenKey(MSRIPv6Path, False);
  if Res then begin
    st := TStringList.Create;
    reg.GetValueNames (st);
    Memo1.Clear;
    for i:=0 to st.Count-1 do begin
      Memo1.Lines.Add (reg.ReadString(st.Strings[i]));
    end;
    st.Free;
  end;
  Memo1.Modified := false;
{  FillChar(SI, SizeOf(SI), 0);
  SI.cb := SizeOf(SI);
  res := CreateProcess (NIL, 'ipv6 if', NIL, NIL,
                 False, 0, NIL, NIL, SI, PI);
  SHowMessage ('CreateProcess return ' + IntToStr(ord(res)) );
  SHowMessage ('GetLastError=' + IntToStr(GetLastError) );}
end;

procedure TForm1.bSaveClick(Sender: TObject);
begin
  if Application.MessageBox ('Are you sure you want to save ' + chr(13) +
              'IPv6 init commands to registry?',
              'Save to registry', MB_OKCANCEL) = IDOK
  then
    SaveToRegistry
end;

procedure TForm1.SaveToRegistry;
var
  reg: TRegistry;
  res: bool;
  st: TStrings;
  i: integer;
begin
  reg := TRegistry.Create;
  Reg.rootkey := HKEY_LOCAL_MACHINE;
  Res := reg.OpenKey(MSRIPv6Path, True);
  if Res then begin
    { Delete current content }
    st := TStringList.Create;
    reg.GetValueNames (st);
    for i:=0 to st.Count-1 do begin
      res := reg.DeleteValue (st.Strings[i]);
      //if NOT res then SHowMessage ('ERROR');
    end;
    st.Free;
    { Write new commands to registry }
    for i:=0 to Memo1.Lines.Count-1 do begin
      reg.WriteString ('cmd' + IntToStr(i+1), Memo1.Lines.Strings[i]);
      //if NOT res then SHowMessage ('ERROR');
    end;
  end;
  Memo1.Modified := false;
end;


procedure TForm1.FormResize(Sender: TObject);
begin
  Memo1.Height := Height - 95;
  Memo1.Width := Width - 45;
end;

procedure TForm1.Button1Click(Sender: TObject);
begin
  ShowUsage
end;

procedure TForm1.FormCloseQuery(Sender: TObject; var CanClose: Boolean);
begin
  if Memo1.Modified then begin
    if Application.MessageBox ('Do you want to save ' + chr(13) +
                'IPv6 init commands to registry?',
                'Save to registry', MB_YESNO) = IDYES
    then
      SaveToRegistry
  end;
end;

end.
